@@ -2,8 +2,6 @@
 This module includes functions related to the event API endpoint.
 """
 
-from copy import deepcopy
-
 from datetime import timedelta
 
 from django.conf import settings
@@ -11,26 +9,29 @@ from django.http import JsonResponse
 from django.utils import timezone
 from django.utils.html import strip_tags
 
-from ...cms.models.events.event_translation import EventTranslation
-from ...cms.utils.slug_utils import generate_unique_slug
 from ..decorators import json_response
 from .locations import transform_poi
 
 
-def transform_event(event):
+def transform_event(event, custom_date=None):
     """
     Function to create a JSON from a single event object.
 
     :param event: The event which should be converted
     :type event: ~integreat_cms.cms.models.events.event.Event
 
+    :param custom_date: The date overwrite of the event
+    :type custom_date: ~datetime.date
+
     :return: data necessary for API
     :rtype: dict
     """
     return {
-        "id": event.id,
-        "start_date": event.start_date,
-        "end_date": event.end_date,
+        "id": event.id if not custom_date else None,
+        "start_date": custom_date or event.start_date,
+        "end_date": custom_date + (event.end_date - event.start_date)
+        if custom_date
+        else event.end_date,
         "all_day": event.is_all_day,
         "start_time": event.start_time,
         "end_time": event.end_time,
@@ -39,18 +40,26 @@ def transform_event(event):
     }
 
 
-def transform_event_translation(event_translation):
+def transform_event_translation(event_translation, recurrence_date=None):
     """
     Function to create a JSON from a single event_translation object.
 
     :param event_translation: The event translation object which should be converted
     :type event_translation: ~integreat_cms.cms.models.events.event_translation.EventTranslation
 
+    :param recurrence_date: The recurrence date for the event
+    :type recurrence_date: ~datetime.date
+
     :return: data necessary for API
     :rtype: dict
     """
     event = event_translation.event
-    absolute_url = event_translation.get_absolute_url()
+    slug = (
+        event_translation.slug
+        if not recurrence_date
+        else f"{event_translation.slug}${recurrence_date}"
+    )
+    absolute_url = event_translation.url_prefix + slug + "/"
     return {
         "id": event_translation.id,
         "url": settings.BASE_URL + absolute_url,
@@ -59,14 +68,49 @@ def transform_event_translation(event_translation):
         "modified_gmt": event_translation.last_updated.strftime("%Y-%m-%d %H:%M:%S"),
         "excerpt": strip_tags(event_translation.content),
         "content": event_translation.content,
-        "available_languages": event_translation.available_languages,
+        "available_languages": transform_available_languages(
+            event_translation, recurrence_date
+        )
+        if recurrence_date
+        else event_translation.available_languages_dict,
         "thumbnail": event.icon.url if event.icon else None,
         "location": transform_poi(event.location),
-        "event": transform_event(event),
+        "event": transform_event(event, recurrence_date),
         "hash": None,
     }
 
 
+def transform_available_languages(event_translation, recurrence_date):
+    """
+    Function to create a JSON object of all available translations of an event translation.
+    This is similar to `event_translation.available_languages_dict` embeds the recurrence date in the translation slug.
+
+    :param event_translation: The event translation object which should be converted
+    :type event_translation: ~integreat_cms.cms.models.events.event_translation.EventTranslation
+
+    :param recurrence_date: The date of this event translation
+    :type recurrence_date: ~datetime.date
+
+    :return: data necessary for API
+    :rtype: dict
+    """
+    languages = {}
+
+    for translation in event_translation.foreign_object.available_translations():
+        if translation.language == event_translation.language:
+            continue
+
+        slug = f"{translation.slug}${recurrence_date}"
+        path = translation.url_prefix + slug + "/"
+        languages[translation.language.slug] = {
+            "id": None,
+            "url": settings.BASE_URL + path,
+            "path": path,
+        }
+
+    return languages
+
+
 def transform_event_recurrences(event_translation, today):
     """
     Yield all future recurrences of the event.
@@ -93,12 +137,9 @@ def transform_event_recurrences(event_translation, today):
     ):
         return
 
-    event_length = event.end_date - event.start_date
     start_date = event.start_date
     event_translation.id = None
-    # Store language and slug for usage in loop
-    current_language = event_translation.language
-    current_slug = event_translation.slug
+
     # Calculate all recurrences of this event
     for recurrence_date in recurrence_rule.iter_after(start_date):
         if recurrence_date - max(start_date, today) > timedelta(
@@ -107,52 +148,8 @@ def transform_event_recurrences(event_translation, today):
             break
         if recurrence_date < today or recurrence_date == start_date:
             continue
-        # Create all temporary translations of this recurrence
-        recurrence_translations = {}
-        if event.region.fallback_translations_enabled:
-            languages = event.region.active_languages
-        else:
-            languages = event.public_languages
-        for language in languages:
-            # Create copy in memory to make sure original translation is not affected by changes
-            event_translation = deepcopy(event_translation)
-            # Fake the requested language
-            event_translation.language = language
-            event_translation.slug = generate_unique_slug(
-                **{
-                    "slug": f"{current_slug}-{recurrence_date}",
-                    "manager": EventTranslation.objects,
-                    "object_instance": event_translation,
-                    "foreign_model": "event",
-                    "region": event.region,
-                    "language": language,
-                }
-            )
-            # Reset id to make sure id does not conflict with existing event translation
-            event_translation.event.id = None
-            # Set date to recurrence date
-            event_translation.event.start_date = recurrence_date
-            event_translation.event.end_date = recurrence_date + event_length
-            # Clear cached property in case url with different language was already calculated before
-            try:
-                del event_translation.url_prefix
-            except AttributeError:
-                pass
-            recurrence_translations[language.slug] = event_translation
 
-        # Set the prefetched public translations to make sure the recurrence translations are correctly listed in available languages
-        for recurrence_translation in recurrence_translations.values():
-            recurrence_translation.event.prefetched_public_translations_by_language_slug = (
-                recurrence_translations
-            )
-        # Update translation object with the one with prefetched temporary translations
-        event_translation = recurrence_translations[current_language.slug]
-        # Clear cached property in case available languages with different recurrence was already calculated before
-        try:
-            del event_translation.available_languages
-        except AttributeError:
-            pass
-        yield transform_event_translation(event_translation)
+        yield transform_event_translation(event_translation, recurrence_date)
 
 
 @json_response
