@@ -92,6 +92,11 @@ media_ajax_urlpatterns = [
                                 media.edit_file_ajax,
                                 name="mediacenter_edit_file",
                             ),
+                            path(
+                                "move/",
+                                media.move_file_ajax,
+                                name="mediacenter_move_file",
+                            ),
                             path(
                                 "delete/",
                                 media.delete_file_ajax,
